========================================
 Installing Database Drivers for Oracle
========================================

.. tip:: See :doc:`../install` for the easiest way to get the best
         drivers.

The only tested driver is cx_Oracle 6.0+.

.. note:: PyPy is not tested with Oracle.
